Installation
============

Requirements
------------

.. todo::

Installing
----------

The complete IRCO suite, including its requirements, can be installed though
``pip`` by issuing the followin command::

    pip install irco

Upgrading
---------

It is possible to upgrade the IRCO tool to its latest version by issuing the
following command::

    pip install --upgrade irco
